SET FOREIGN_KEY_CHECKS=0;

DROP DATABASE IF EXISTS `coop`;

CREATE DATABASE `coop`;

USE `coop`;

#
# Structure for the `portal` table : 
#

DROP TABLE IF EXISTS `portal`;

CREATE TABLE `portal` (
  `id` int(11) NOT NULL auto_increment,
  `descripcion` varchar(100) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

#
# Structure for the `productos` table : 
#

DROP TABLE IF EXISTS `productos`;

CREATE TABLE `productos` (
  `id` int(11) NOT NULL auto_increment,
  `portal_id` int(11) NOT NULL default '1',
  `nombre` varchar(200) NOT NULL,
  `descripcion` text NOT NULL,
  `imagen` varchar(200) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `id` (`id`),
  UNIQUE KEY `nombre` (`nombre`),
  KEY `portal_id` (`portal_id`),
  CONSTRAINT `productos_ibfk_1` FOREIGN KEY (`portal_id`) REFERENCES `portal` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

#
# Structure for the `noticias` table : 
#

DROP TABLE IF EXISTS `noticias`;

CREATE TABLE `noticias` (
  `id` int(11) NOT NULL auto_increment,
  `portal_id` int(11) NOT NULL,
  `titulo` varchar(200) NOT NULL,
  `fecha` date NOT NULL,
  `descripcion` text NOT NULL,
  `destacada` char(1) NOT NULL default 'N',
  `imagen` varchar(100) default NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `id` (`id`),
  KEY `portal_id` (`portal_id`),
  CONSTRAINT `noticias_ibfk_1` FOREIGN KEY (`portal_id`) REFERENCES `portal` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

#
# Structure for the `datos_estaticos` table : 
#

DROP TABLE IF EXISTS `datos_estaticos`;

CREATE TABLE `datos_estaticos` (
  `id` int(11) NOT NULL auto_increment,
  `historia` text NOT NULL,
  `compromiso_social` text NOT NULL,
  `dueto_producto` text,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

#
# Structure for the `cgrefcodes` table : 
#

DROP TABLE IF EXISTS `cgrefcodes`;

CREATE TABLE `cgrefcodes` (
  `id` int(11) NOT NULL auto_increment,
  `dominio` varchar(100) NOT NULL,
  `minimo` int(11) default NULL,
  `maximo` int(11) default NULL,
  `descripcion` varchar(255) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

#
# Data for the `portal` table  (LIMIT 0,500)
#

# id:3:49671
# descripcion:253:4097

INSERT INTO `portal` (`id`, `descripcion`) VALUES 
  (1,'Institucional'),
  (2,'Dueto'),
  (3,'Tropicana');

COMMIT;

#
# Data for the `productos` table  (LIMIT 0,500)
#

# id:3:49671
# portal_id:3:49161
# nombre:253:20485
# descripcion:252:4113
# imagen:253:4097

INSERT INTO `productos` (`id`, `portal_id`, `nombre`, `descripcion`, `imagen`) VALUES 
  (1,1,'Leche Entera Pasteurizada','En sachet de 1 litro y 1/2 litro, como recin ordeada. Se conserva a temperatura inferior a 5 grados.','prod-lech-ent-past.jpg'),
  (2,1,'Leche Descremada Pasteurizada',' Adicionada con vitaminas A y D, en sachet de 1 litro. Se conserva a temperatura inferior a 5 grados.','prod-lech-desc-past.jpg'),
  (3,1,'Leche Entera UAT larga vida','Enriquecida con 6 nutrientes escenciales, slo 3% de grasa y sin conservantes, en envases Tetra Pak de 1 litro con tapa Recap para abrir y cerrar fcilmente.','prod-lech-uat-larg.jpg'),
  (4,1,'Leche Descremada UAT Vida','Enriquecida con Vitamina A y D3, con 0% de grasa y sin conservantes, en envases Tetra Pak de 1 litro con tapa Recap para abrir y cerrar fcilmente.','prod-lech-desc-vida.jpg'),
  (5,1,'Yoghurt Entero','De textura espesa con pulpa de frutas en los sabores Frutilla, Coco, Durazno y Vainilla, en potes de 140 g y 350 g.','prod-yogh-ent.jpg'),
  (6,1,'Yoghurt Bebible','En los sabores Frutilla, Coco, Durazno y Vainilla, en potes de 200 ml y sachets de 500 ml y de 1 litro.','prod-yogh-bebib.jpg'),
  (7,1,'Yoghurt Winnie the Pooh','Yoghurt entero bebible de textura semi espesa con agregado de Miel y Vitaminas, sabor Frutilla y Vainilla en sachets de 200 ml','prod-yogh-winnie.jpg'),
  (8,1,'Yoghurt Diettico Vida','Yoghurt descremado diettico en sabores Frutilla, Coco y Vainilla, en potes de 140 g y 350 g y en potes de 150 g con cereal Muslix de Kelloggs.','prod-yogh-diet-vida.jpg'),
  (9,1,'Yoghurt Dueto','Yoghurt entero en potes de 150 g y nuevo pote de 140 g con cucharita includa, con los cereales Zucaritas y Froot Loops de Kelloggs.','prod-yogh-dueto.jpg'),
  (10,1,'Bebida Lctea Tropicana','Leche fermentada en los sabores vainilla, banana y frutilla, en potes de 140 ml y sachets de 500 ml y\r\n1 litro.','prod-beb-tropic.jpg'),
  (11,1,'Yoghurt Disfrut','Yoghurt bebible con mix de pulpa de frutas, sabor banana y manzana, frambuesa y frutilla, en prcticas botellitas de 200 ml.','prod-yogh-disfru-vida.jpg'),
  (12,1,'Dulce de Leche','Dulce de Leche para untar en potes de 220 g y 470 g. Tambin de tipo repostero en sachet de 500 g y 1 kilo.','prod-dulce-leche.jpg'),
  (13,1,'Crema de Leche','Crema de Leche fresca, en potes de 350 g y sachet de 500 ml y 1 litro.','prod-crem-lech.jpg'),
  (14,1,'Manteca','Manteca sin sal en panes de 200 gramos.','prod-manteca.jpg'),
  (15,1,'Queso Cuartirolo','Queso de sabor suave para mesa o cocina, en hormas de 1 y 3 kg (aprox.) envasados al vaco.','prod-ques-cuart.jpg'),
  (16,1,'Queso magro cuartirolo Vida','Queso hecho a base de leche semidescremada, hormas de 430 g (aprox.) envasado al vaco.','prod-ques-cuar-vid.jpg'),
  (17,1,'Queso fundido','Queso fundido para untar, en sabor salame, jamn y pimienta en potes de 250 g.','prod-ques-fun-vid.jpg'),
  (18,1,'Descremado fundido Vida','Queso descremado fundido para untar, sabor jamn en potes de 250 g.','prod-ques-fun-vid.jpg'),
  (19,1,'Quesa Sandwich Dambo','Queso suave y aromtico para toda hora, en hormas de 3 kg (aprox.) y en rebanadas de 20 fetas envasados al vaco.','prod-ques-sandw.jpg'),
  (20,1,'Queso tipo Holanda','Queso tipo Holanda, en hormas de 3 Kg. (aprox.) envasado al vaco','prod-ques-hol.jpg');

COMMIT;

#
# Data for the `noticias` table  (LIMIT 0,500)
#

# id:3:49671
# portal_id:3:53257
# titulo:253:4097
# fecha:10:4225
# descripcion:252:4113
# destacada:254:1
# imagen:253:0

INSERT INTO `noticias` (`id`, `portal_id`, `titulo`, `fecha`, `descripcion`, `destacada`, `imagen`) VALUES 
  (1,1,'CO-COP lanza su leche descremada','2007-08-13','CO-OP ofrece una nueva forma de alimentarse y cuidar la figura. La leche descremada UAT Vida posee todos los nutrientes de la leche entera, pero sin grasa y fortificada con Vitamina A y Vitamina D3 que ayudan a retener el Calcio y el Fsforo.','N','img-noti1.jpg'),
  (2,1,'Nueva Leche Entera con ms nutrientes','2007-08-13','Coop lanz al mercado su nueva Leche Entera UAT, uniendo todo lo que necesitamos para nuestro desarrollo fsico en un poderoso paquete de 6 nutrientes esenciales. Los elementos con los que cuenta esta leche son: vitamina B-12, vitamina B6; Vitamina, Vitamina A, Fsforo y calcio.\r\nAdems, la nueva leche Entera UAT no contiene conservantes, cuenta con slo 3,5% de grasa y viene en el novedoso envase Tetra Brik Aseptic de Tetra Pack garantizando una duracin de 6 meses cerrado y con una prctica tapa ReCap que permite abrir y cerrar fcilmente una vez abierto. Por todo esto la nueva Leche UAT de COOP se constituye en la opcin ms completa, prctica y sana a la hora de consumir leche.','S','img-noti1.jpg'),
  (3,1,'Disfrut CO-OP','2007-08-13','Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old. Richard McClintock, a Latin professor at Hampden-Sydney College in Virginia, looked up one of the more obscure Latin words, consectetur, from a Lorem Ipsum passage, and going through the cites of the word in classical literature, discovered the undoubtable source. Lorem Ipsum comes from sections 1.10.32 and 1.10.33 of \"de Finibus Bonorum et Malorum\" (The Extremes of Good and Evil) by Cicero, written in 45 BC. This book is a treatise on the theory of ethics, very popular during the Renaissance. The first line of Lorem Ipsum, \"Lorem ipsum dolor sit amet..\", comes from a line in section 1.10.32.\r\n\r\nThe standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections 1.10.32 and 1.10.33 from \"de Finibus Bonorum et Malorum\" by Cicero are also reproduced in their exact original form, accompanied by English versions from the 1914 translation by H. Rackham.','N','img-noti1.jpg'),
  (4,1,'Dueto lanza su nuevo envase','2007-08-13','Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry\'s standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.\r\n\r\nContrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old. Richard McClintock, a Latin professor at Hampden-Sydney College in Virginia, looked up one of the more obscure Latin words, consectetur, from a Lorem Ipsum passage, and going through the cites of the word in classical literature, discovered the undoubtable source. Lorem Ipsum comes from sections 1.10.32 and 1.10.33 of \"de Finibus Bonorum et Malorum\" (The Extremes of Good and Evil) by Cicero, written in 45 BC. This book is a treatise on the theory of ethics, very popular during the Renaissance.','N','img-noti1.jpg');

COMMIT;

#
# Data for the `datos_estaticos` table  (LIMIT 0,500)
#

# id:3:49671
# historia:252:4113
# compromiso_social:252:4113
# dueto_producto:252:16

INSERT INTO `datos_estaticos` (`id`, `historia`, `compromiso_social`, `dueto_producto`) VALUES 
  (1,'CO-OP nace de la unin de dos colonias: Neuland y Fernheim. Ambas, llegaron al Chaco paraguayo hace aproximadamente 60 aos, con ganas de trabajar, superar obstculos y sobretodo, construir un hogar.\r\n\r\nAs lo hicieron. En el Chaco encontraron eso que buscaron en otros continentes: un hogar. Sin embargo, al asentarse, descubrieron una tierra que no les ofreca las condiciones necesarias para sus propsitos. Una vez ms, la tarea no era fcil.\r\n\r\nPero fue ms fuerte el ingenio y la voluntad para vencer adversidades. Ellos vieron el potencial del suelo chaqueo y lo aprovecharon utilizando tcnicas y mtodos que luego perfeccionaron. Lograron adaptarse a su nuevo hogar sin perder nunca su identidad.\r\n\r\nEn la dcada de los 40 la Colonia Fernheim tuvo buen despegue econmico en el campo, con man y algodn en agricultura as tambin como en ganadera. Sin embargo, a finales de la dcada se dieron cuenta de que algunas familias no formaban parte de ese auge en la economa, all fue cuando pensaron en el rubro lcteo.\r\nEntonces surgi la unin con Neuland y otra cooperativa que ms tarde tomara otro camino. Encontraron un rubro no muy explotado en el pas y que les permita realizarse como colonia en cuanto a trabajo y calidad de vida.\r\n\r\nPor esto, Neuland y Fernheim perseveraron y superaron barreras en pos de sus objetivos. Ante todo, siempre mantuvieron sus principios. Y ellos guiaron todos sus esfuerzos: seriedad, disciplina, pensamiento cooperativo, idoneidad e identidad se vieron entonces reflejados en su trabajo.\r\n\r\nEl primer producto de Lcteos CO-OP fue la leche. Comenzaron con una capacidad de procesamiento inicial de 1000 lts./leche da y evolucionaron hasta la capacidad actual de 150.000 lts./leche da. Luego fueron incorporando otros productos que hoy enriquecen la dieta familiar, entre leches, yogures, dulce de leche, crema de leche, quesos y manteca. Ya en 1994, la distribucin llegaba a todo Paraguay a travs de centros de distribucin en 6 ciudades estratgicas.\r\n\r\nLos productos CO-OP son elaborados a base de materia prima controlada y sin conservantes, lo que asegura sabor y calidad para los consumidores. La investigacin y desarrollo de nuevos productos, las modernas tecnologas internacionales de produccin, la cuidadosa seleccin de materia prima hacen de que la Cooperativa sea un modelo de desarrollo.\r\n\r\nHoy, Lcteos CO-OP es uno de los principales productores de lcteos en el pas','Adems de producir alimentos de calidad para el pblico, tanto Neuland como Fernheim asumen un compromiso con la sociedad de la que son parte. Por eso, la cooperativa Neuland ayuda a los vecinos de la zona de Pirizal, situado a 100 Km. del centro de la Colonia con el objetivo de mejorar la calidad de vida de los habitantes.\r\n\r\nAdems, ayuda a los indgenas de la zona brindndoles trabajo. Una gran cantidad de ellos trabaja en las colonias como obreros. Tambin han creado una asociacin que provee ayuda para mejorar la vida de los indgenas de distintas parcialidades. Estos reciben asistencia en el rea de produccin agropecuaria, educacin y salud.\r\n\r\nEsto demuestra un vez ms que Neuland y Fernheim son parte activa y productiva del Chaco y de todo el pas.','Dueto es un producto creado por CO-OP en alianza estratgica con Kelloggs, marca reconocida internacionalmente. Juntos, forman la combinacin perfecta: un yogurt, elaborado bajo el ms estricto control de calidad, con Zucaritas de Kelloggs, cereales que complementan la dieta diaria, aportando nutrientes necesarios y buen sabor.\r\n\r\nBajo estas dos premisas: calidad y nutricin nace Dueto. Un producto pensando para satisfacer las necesidades y deseos de los consumidores.\r\n\r\nDueto es la combinacin ideal para todos aquellos que disfruten haciendo deportes o actividades que requieran energa, aquellos que disfruten de las emociones fuertes y de vivir experiencias al lmite.\r\n\r\nPero Dueto no se detiene aqu, ya que innova permanentemente. Gracias a su inters constante en los consumidores y el estudio de sus necesidades, ahora trae una prctica cucharita incorporada, para que en cualquier momento y en cualquier lugar, la gente pueda disfrutarlo. Este nuevo envase brinda la libertad de disfrutar el yogurt con cereales de una forma simple y fcil.');

COMMIT;

#
# Data for the `cgrefcodes` table  (LIMIT 0,500)
#

# id:3:49671
# dominio:253:4097
# minimo:3:32768
# maximo:3:32768
# descripcion:253:4097

INSERT INTO `cgrefcodes` (`id`, `dominio`, `minimo`, `maximo`, `descripcion`) VALUES 
  (1,'MAIL_INFO',NULL,NULL,'micayael@gmail.com'),
  (2,'NOMBRE_INFO',NULL,NULL,'www.coop.com.py'),
  (3,'HOST_MAIL',NULL,NULL,'mail.xxx.net'),
  (4,'ASUNTO_MAIL',NULL,NULL,'Correo enviado desde la Web');

COMMIT;

